@@ -11,11 +11,11 @@ from datetime import datetime
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
-import os
+from pathlib import Path
 import sys
 
-sys.path.insert(0, os.path.abspath("_ext"))
-
+HERE = Path(__file__).parent
+sys.path.insert(0, str(HERE.parent.parent))
 import omnipath
 
 needs_sphinx = "3.0"
@@ -25,7 +25,6 @@ needs_sphinx = "3.0"
 project = "omnipath"
 author = omnipath.__author__
 copyright = f"{datetime.now():%Y}, {author}"
-github_repo = "https://github.com/saezlab/omnipath"
 
 # The full version, including alpha/beta/rc tags
 release = f"master ({omnipath.__version__})"
@@ -42,11 +41,8 @@ extensions = [
     "sphinx.ext.viewcode",
     "sphinx_autodoc_typehints",
     "sphinx.ext.intersphinx",
-    "sphinx_paramlinks",
     "sphinx.ext.autosummary",
     "sphinx_last_updated_by_git",
-    "edit_on_github",
-    "enum_tools.autoenum",
 ]
 intersphinx_mapping = dict(
     python=("https://docs.python.org/3", None),
@@ -92,11 +88,6 @@ html_static_path = ["_static"]
 html_theme_options = dict(navigation_depth=4, logo_only=True)
 html_show_sphinx = False
 
-# Add any paths that contain custom static files (such as style sheets) here,
-# relative to this directory. They are copied after the builtin static files,
-# so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ["_static"]
-
 
 def setup(app):
     app.add_css_file("css/custom.css")
