@@ -1,4 +1,4 @@
-from omnipath._core.requests._request import Enzsub
+from omnipath._core.requests._request import Enzsub, SignedPTMs
 from omnipath._core.requests._complexes import Complexes
 from omnipath._core.requests._intercell import Intercell
 from omnipath._core.requests._annotations import Annotations
