@@ -68,7 +68,7 @@ class OmnipathRequestABC(ABC, metaclass=OmnipathRequestMeta):
 
     _json_reader = _error_handler(partial(pd.read_json, typ="frame"))
     _tsv_reader = _error_handler(
-        partial(pd.read_csv, sep="\t", header=0, squeeze=False)
+        partial(pd.read_csv, sep="\t", header=0, squeeze=False, low_memory=False)
     )
     _query_type: Optional[QueryType] = None
 
@@ -424,9 +424,8 @@ class GraphLike(ABC):
             import networkx as nx
         except ImportError:
             raise ImportError(
-                "Unable to import `networkx`. Please install it as `pip install network`."
+                "Unable to import `networkx`. Please install it as `pip install networkx`."
             ) from None
-
         data = cls.get(**kwargs) if data is None else data
 
         if not isinstance(data, pd.DataFrame):
